@@ -5,3 +5,6 @@
 from .singlepop_model import SinglePopModel
 from .twopop_model import TwoPopModel
 from .vdp_forger99_model import vdp_forger99_model
+from ..plots import *
+from ..utils import * 
+from ..light_schedules import *
